pandas I/O
==========

Functions for loading data from pandas and exporting results.

Creating Sets
-------------

.. autofunction:: cvxpy_or.set_from_series

.. autofunction:: cvxpy_or.set_from_dataframe

.. autofunction:: cvxpy_or.set_from_index

Creating Parameters
-------------------

.. autofunction:: cvxpy_or.parameter_from_dataframe

.. autofunction:: cvxpy_or.parameter_from_series

Exporting Results
-----------------

.. autofunction:: cvxpy_or.variable_to_dataframe

.. autofunction:: cvxpy_or.parameter_to_dataframe
